Class: RubyLens::ArtModelBuilder::Dependencies

Inherits:
Data
  • Object
show all
Defined in:
lib/rubylens/art_model_builder.rb

Overview

Unlike the other two, this index is not an inverse of any stored order: a dependency star's snapshot ordinal is only known for rows travel targets, and is captured as the shuffled rows are emitted.

Instance Attribute Summary collapse

Instance Attribute Details

#indexObject (readonly)

Returns the value of attribute index

Returns:

  • (Object)

    the current value of index



50
51
52
# File 'lib/rubylens/art_model_builder.rb', line 50

def index
  @index
end

#rowsObject (readonly)

Returns the value of attribute rows

Returns:

  • (Object)

    the current value of rows



50
51
52
# File 'lib/rubylens/art_model_builder.rb', line 50

def rows
  @rows
end