Class: RubyLens::ArtModelBuilder::Dependencies
- Inherits:
-
Data
- Object
- Data
- RubyLens::ArtModelBuilder::Dependencies
- Defined in:
- lib/rubylens/art_model_builder.rb
Overview
Unlike the other two, this index is not an inverse of any stored order: a dependency star's snapshot ordinal is only known for rows travel targets, and is captured as the shuffled rows are emitted.
Instance Attribute Summary collapse
-
#index ⇒ Object
readonly
Returns the value of attribute index.
-
#rows ⇒ Object
readonly
Returns the value of attribute rows.
Instance Attribute Details
#index ⇒ Object (readonly)
Returns the value of attribute index
50 51 52 |
# File 'lib/rubylens/art_model_builder.rb', line 50 def index @index end |
#rows ⇒ Object (readonly)
Returns the value of attribute rows
50 51 52 |
# File 'lib/rubylens/art_model_builder.rb', line 50 def rows @rows end |